@@ -1,31 +1,27 @@
 package App::CharmKit::Command::clean;
-$App::CharmKit::Command::clean::VERSION = '0.003_3';
-# ABSTRACT: Cleans project
+$App::CharmKit::Command::clean::VERSION = '0.002';
+# ABSTRACT: Cleanses project
 
 
 use App::CharmKit -command;
 use Path::Tiny;
 
 use Moo;
-with 'App::CharmKit::Role::Clean';
 use namespace::clean;
 
 sub opt_spec {
     return ();
 }
 
+sub abstract { 'Cleanses project'}
 sub usage_desc {'%c clean'}
 
 sub execute {
     my ($self, $opt, $args) = @_;
-
-    my @paths_to_rm = path('tests')->children(qr/\.test/);
-    if (path('fatlib')->exists) {
-        push @paths_to_rm, path('fatlib');
+    my $path = path('.');
+    if ($path->child('fatlib')->exists) {
+        $path->child('fatlib')->remove_tree;
     }
-    push @paths_to_rm, path('hooks')->children;
-    $self->clean(\@paths_to_rm);
-    print("Finished cleaning project.\n");
 }
 
 1;
@@ -38,11 +34,11 @@ __END__
 
 =head1 NAME
 
-App::CharmKit::Command::clean - Cleans project
+App::CharmKit::Command::clean - Cleanses project
 
 =head1 VERSION
 
-version 0.003_3
+version 0.002
 
 =head1 SYNOPSIS
 
