@@ -1,6 +1,6 @@
 package App::CharmKit::Command::init;
-$App::CharmKit::Command::init::VERSION = '0.003_3';
-# ABSTRACT: Generate a charm project
+$App::CharmKit::Command::init::VERSION = '0.002';
+# ABSTRACT: Initialization of project
 
 
 
@@ -25,6 +25,7 @@ sub opt_spec {
     );
 }
 
+sub abstract { 'Generate a charm skeleton.'}
 sub usage_desc {'%c init [--options] <charm-name>'}
 
 sub validate_args {
@@ -109,11 +110,11 @@ __END__
 
 =head1 NAME
 
-App::CharmKit::Command::init - Generate a charm project
+App::CharmKit::Command::init - Initialization of project
 
 =head1 VERSION
 
-version 0.003_3
+version 0.002
 
 =head1 SYNOPSIS
 
