@@ -1,5 +1,5 @@
 package App::CharmKit::Command::pack;
-$App::CharmKit::Command::pack::VERSION = '0.003_3';
+$App::CharmKit::Command::pack::VERSION = '0.002';
 # ABSTRACT: Package hooks for distribution
 
 
@@ -14,6 +14,7 @@ sub opt_spec {
     return ();
 }
 
+sub abstract { 'Build distributable hooks for charm deployment'}
 sub usage_desc {'%c pack'}
 
 sub execute {
@@ -35,7 +36,7 @@ App::CharmKit::Command::pack - Package hooks for distribution
 
 =head1 VERSION
 
-version 0.003_3
+version 0.002
 
 =head1 SYNOPSIS
 
