@@ -1,12 +1,9 @@
 package App::CharmKit::Helper;
-$App::CharmKit::Helper::VERSION = '0.003_3';
+$App::CharmKit::Helper::VERSION = '0.002';
 # ABSTRACT: charm helpers
 
 
 use App::CharmKit::Sys qw/execute/;
-use YAML::Tiny;
-use JSON::PP;
-use Text::MicroTemplate;
 use Exporter qw/import/;
 
 our @EXPORT = qw/config_get
@@ -16,16 +13,7 @@ our @EXPORT = qw/config_get
   relation_list
   open_port
   close_port
-  unit_get
-  json
-  yaml
-  tmpl/;
-
-sub json { JSON::PP->new->utf8; }
-
-sub yaml { YAML::Tiny->new(@_); }
-
-sub tmpl { Text::MicroTemplate->new(@_); }
+  unit_get/;
 
 sub service_control {
     my $service_name = shift;
@@ -128,7 +116,7 @@ App::CharmKit::Helper - charm helpers
 
 =head1 VERSION
 
-version 0.003_3
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -136,7 +124,7 @@ version 0.003_3
 
 or
 
-  use charm;
+  use charm -helper;
 
   my $port = config_get 'port';
   my $database = relation_get 'database';
@@ -148,18 +136,6 @@ Charm helpers for composition
 
 =head1 FUNCTIONS
 
-=head2 json
-
-Wrapper for JSON::PP
-
-=head2 yaml
-
-Wrapper for YAML::Tiny
-
-=head2 tmpl
-
-Wrapper for Text::MicroTemplate
-
 =head2 service_control(STR service_name, STR action)
 
 Controls a upstart service
