@@ -1,5 +1,5 @@
 package App::CharmKit::Role::Init;
-$App::CharmKit::Role::Init::VERSION = '0.003_3';
+$App::CharmKit::Role::Init::VERSION = '0.002';
 # ABSTRACT: Initialization of new charms
 
 use Carp;
@@ -65,7 +65,7 @@ done_testing;
     $yaml = YAML::Tiny->new(
         {   options => {
                 supports_charmkit => {
-                    default => 1,
+                    default => 'true',
                     description =>
                       'Supports extended functionality from App::CharmKit',
                     type => 'boolean'
@@ -120,7 +120,7 @@ App::CharmKit::Role::Init - Initialization of new charms
 
 =head1 VERSION
 
-version 0.003_3
+version 0.002
 
 =head1 METHODS
 
