@@ -1,12 +1,12 @@
 package App::CharmKit::Sys;
-$App::CharmKit::Sys::VERSION = '0.003_3';
+$App::CharmKit::Sys::VERSION = '0.002';
 # ABSTRACT: system utilities
 
 
 use IPC::Run qw(run timeout);
 use Exporter qw(import);
 
-our @EXPORT = qw/execute apt_inst apt_upgrade apt_update/;
+our @EXPORT = qw/execute apt_inst/;
 
 sub execute {
     my ($command) = @_;
@@ -29,18 +29,6 @@ sub apt_inst {
     return $ret->{stdout};
 }
 
-sub apt_upgrade {
-    my $cmd = ['apt-get', '-qyf', 'dist-upgrade'];
-    my $ret = execute($cmd);
-    return $ret->{stdout};
-}
-
-sub apt_update {
-    my $cmd = ['apt-get', 'update'];
-    my $ret = execute($cmd);
-    return $ret->{stdout};
-}
-
 1;
 
 __END__
@@ -55,19 +43,20 @@ App::CharmKit::Sys - system utilities
 
 =head1 VERSION
 
-version 0.003_3
+version 0.002
 
 =head1 SYNOPSIS
 
-  use charm -sys;
+use charm -sys;
 
 or
 
-  use App::CharmKit::Sys;
+use App::CharmKit::Sys;
 
-  apt_update();
-  apt_upgrade();
-  apt_inst(['nginx-common', 'redis-server']);
+# Exposes Path::Tiny
+my $curpath = path('.');
+my $homepath = path('~');
+$homepath->child('.config')->mkpath;
 
 =head1 DESCRIPTION
 
@@ -87,19 +76,7 @@ Executes a local command:
 
 Installs packages via apt-get
 
-   apt_inst(['nginx']);
-
-=head2 apt_upgrade()
-
-Upgrades system
-
-   apt_upgrade();
-
-=head2 apt_update()
-
-Update repository sources
-
-   apt_update();
+   apt_inst ['nginx'];
 
 =head1 AUTHOR
 
