@@ -1,5 +1,5 @@
 package charm;
-$charm::VERSION = '0.003_3';
+$charm::VERSION = '0.002';
 # ABSTRACT: charm helpers for App::CharmKit
 
 
@@ -10,8 +10,10 @@ use warnings;
 use Import::Into;
 
 use feature ();
-use Path::Tiny;
+use Path::Tiny qw(path);
+use Text::MicroTemplate;
 use Test::More;
+use Carp qw(croak);
 
 sub import {
     my $target = caller;
@@ -24,13 +26,13 @@ sub import {
     'warnings'->import::into($target);
     'utf8::all'->import::into($target);
     'autodie'->import::into($target, ':all');
-    'feature'->import::into($target, ':5.14');
+    'feature'->import::into($target, ':5.10');
     'English'->import::into($target, '-no_match_vars');
-    Path::Tiny->import::into($target, qw(path));
 
     if ($flags{sys}) {
         require 'App/CharmKit/Sys.pm';
         'App::CharmKit::Sys'->import::into($target);
+        Path::Tiny->import::into($target, qw(path));
     }
 
     if ($flags{tester}) {
@@ -44,6 +46,8 @@ sub import {
     require 'App/CharmKit/Logging.pm';
     'App::CharmKit::Logging'->import::into($target);
 
+    Text::MicroTemplate->import::into($target, ':all');
+
 }
 
 1;
@@ -60,11 +64,11 @@ charm - charm helpers for App::CharmKit
 
 =head1 VERSION
 
-version 0.003_3
+version 0.002
 
 =head1 SYNOPSIS
 
-  use charm;
+use charm;
 
 =head1 DESCRIPTION
 
@@ -72,11 +76,11 @@ Exposing helper subs from various packages that would be useful in writing
 charm hooks. Including but not limited too strict, warnings, utf8, Path::Tiny,
 etc ..
 
-    use App::CharmKit::Sys;
+    use charm -sys;
 
 or ..
+    use App::CharmKit::Sys;
 
-    use charm -sys, -logging;
     my $ret = execute ['ls', '/tmp'];
     print($ret->{stdout});
     log 'went to the park';
@@ -85,45 +89,9 @@ or ..
 
 List of modules exported by helper:
 
-=over 4
+L<Path::Tiny::path>
 
-=item *
-
-L<Path::Tiny>
-
-Exposes B<path> routine
-
-=item *
-
-L<YAML::Tiny>
-
-Exposes object as B<yaml>
-
-=item *
-
-L<JSON::PP>
-
-Exposes object as B<json>
-
-=item *
-
-L<Text::MicroTemplate>
-
-Exposes object as B<tmpl>
-
-=item *
-
-L<Test::More>
-
-=item *
-
-L<autodie>
-
-=item *
-
-L<utf8::all>
-
-=back
+L<Carp::croak>
 
 =head1 AUTHOR
 
